<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:output method="html" version="4.0" encoding="UTF-8" indent="yes"/>

<xsl:variable name="url_factory" select="document(/help/url-path)/factory"/>
<xsl:variable name="legal" select="document(/help/legal-path)/legal"/>
<xsl:variable name="app_name" select="$legal/title"/>
<xsl:variable name="first_line" select="$legal/first_line"/>

<xsl:template match="help">
  <html>
    <xsl:attribute name="dir">
      <xsl:value-of select="document('dir.xml')/dir"/>
    </xsl:attribute>
  <head>
    <title><xsl:value-of select="$app_name"/></title>
  </head>
  <body>

  <style type="text/css" xml:space="preserve">
    <xsl:value-of select="document('online_css.xml')/css"/>
    html, body, h1, h2, h3, h4, h5, h6, p, dl, dt, dd, div, blockquote, caption, pre.long, td, th, div.label { font-size: 10pt; line-height: 12pt; }
    html, body, h5, h6, p, dl, dt, dd, div, blockquote, caption, pre.long, th, h2.sectiontitle, div.label { vertical-align: bottom; }
    td { vertical-align: top; }
    h3.topictitle3 { margin-top: 20pt; margin-bottom: 10pt; }
    body { font-family: verdana, arial, helvetica, sans-serif; }
    h1, h2, h3, h4, h5, h6, .label, #prodname { color: #CC0033; font-family: verdana, arial, helvetica, sans-serif; }
    h1#title { line-height: 1.1em; }
    div.related div.label { color: #000000; }
    .label { margin-top: 10pt; font-weight: bold; }
    dt.dlterm { color: #CC0033; font-weight: bold; }
    ul, ol { margin-bottom: 4pt !important; margin-top: 4pt !important; }
    .prereq .label { /* We don't want the margin within the gray-shaded area; we want it outside */ margin-top: 0pt; }
    .prereq { padding: 5pt; /* We don't want the margin within the gray-shaded area; we want it outside */ margin-top: 10pt; margin-left: 15pt; margin-right: 15pt; border: 1pt solid #cc0033; }
    div.example { padding: 0pt 5pt 0pt 5pt; /* We don't want the margin within the gray-shaded area; we want it outside */ margin-top: 10pt; margin-left: 15pt; margin-right: 15pt; border: 1pt solid black; }
    .prereq p { margin-top: 0pt; }
    .prereq .last_p { margin-bottom: 0pt; }
    .note div { float: left; padding-top:6px; list-style: none; display: block; }
    .notelabel { font-size: 10pt; line-height: 12pt; font-weight: bold; color: #CC0033; text-align: left; margin-left: 6pt; margin-right: 6pt; padding-top:13px!important; }
    .notetext { padding-bottom: 8pt !important; padding-left: 6pt; padding-right: 6pt; width: 70%; }
    .notetext, .notetext p { background: #e5e5e5; font-size: 10pt; line-height: 10pt; margin-top: 6pt; margin-bottom: 0pt; padding-bottom: 0pt; }
    .notebuffer { clear: both; height: 3pt; }
    img { vertical-align: text-bottom; }
    .copyright { margin-top: 45pt; font-size: 90%; }
    .familylinks { margin-top: 10pt; }
    span.filepath { font-family: monospace; }
    .endnotes { margin-top: 10pt; font-size: 90%; }
    sup.footnote { font-size: 90%; }
    a.footnoteLink { text-decoration: none; }
    .how { margin-top: 5pt; margin-left: 15pt; margin-right: 15pt; text-decoration: none; color: blue; }
    div.figcap { margin-top: 5pt; font-weight: bold; color: #CC0033; }
    h2 { margin-bottom: 0.4em !important; }
    h2.sectiontitle { margin-bottom: -1em !important; }
    h1.topictitle1 { margin-top: 5pt; }
    .optiondef { margin-top: 5px; margin-bottom: 1px; }
    .bullet { font-size: 7pt; line-height: 10pt; font-family: verdana, arial, helvetica, sans-serif; }
    .disc { font-size: 16pt; line-height: 8pt; }
    .copyright_t { color: #CC0033; font-weight: bold; font-size: 8pt; line-height: 9pt; }
    #copyright_t1, #copyright_t2, #copyright_t3 { margin-top: 12pt; margin-bottom: 0pt; }
    #copyright_t4, #copyright_t5 { margin-top: 6pt; margin-bottom: 0pt; }
    .copyright_p { font-size: 7pt; margin-top: 0pt; line-height: 9pt; }
    div.p { margin-top: 1em; margin-bottom: 1em; }
    div.draft-comment { border: 1pt solid black; color: #cc0033; margin-top: 10pt; margin-bottom: 10pt; }
    pre.codeblock { background: #e5e5e5; margin-left: 4pt; margin-right: 4pt; padding: 5pt; font-size: 8pt; line-height: 9pt; }
    .stepresult { margin-top:1em; }
    div.top-of-page { margin-top: 2em; margin-left: 20pt; }
    div.cluster-links { margin-top: 1em; }
    .maptoc{} .dropped { font-size: 30pt; line-height: 34pt; color: green; }
    .uicontrol-narrow{font-weight: bold; font-family: 'Arial Narrow Bold'; font-size: 10pt;}
  </style>

  <div id="title" class="title">
    <h1><p><xsl:value-of select="$first_line"/></p><p><xsl:value-of select="$app_name"/></p></h1>
  </div>
  
  <div id="index" class="index">
    <ul>
    <xsl:for-each select="document(module-path)/feature-group">
      <div class="{@id}">
      <li><a href="#{@id}"><xsl:apply-templates select="name"/></a></li>
      <ul>
      <xsl:for-each select="feature">
        <div class="{@id}">
        <li><a href="#{@id}"><xsl:value-of select="name"/></a></li>
        </div>
      </xsl:for-each>
      </ul>
      </div>
    </xsl:for-each>
    </ul>
  </div>
  
  <xsl:for-each select="document(module-path)">
    <xsl:apply-templates select="feature-group"/>
  </xsl:for-each>
  
  <xsl:if test="$legal/footer">
    <hr></hr>
  </xsl:if>
  <xsl:apply-templates select="$legal/footer"/>
  
  </body>
  </html>

</xsl:template>

<xsl:template match="feature-group">
  <div id="{@id}" class="{@id}">
    <h2><a name="{@id}"><xsl:apply-templates select="name"/></a></h2>
    <xsl:apply-templates select="desc|ulist|olist|note"/>
    <xsl:apply-templates select="feature"/>
  </div>
</xsl:template>

<xsl:template match="feature">
  <div id="{@id}" class="{@id}">
    <h3><a name="{@id}"><xsl:value-of select="name"/></a></h3>
    <xsl:apply-templates select="desc|olist|ulist|note|sep"/>
  </div>
</xsl:template>

<xsl:template match="olist">
  <xsl:if test="name">
    <div class="label"><xsl:value-of select="name"/></div>
  </xsl:if>
  <xsl:if test="item">
    <ol><xsl:apply-templates select="item"/></ol>
  </xsl:if>
</xsl:template>

<xsl:template match="ulist">
  <xsl:if test="name">
    <div class="label"><xsl:value-of select="name"/></div>
  </xsl:if>
  <xsl:if test="item">
    <ul><xsl:apply-templates select="item"/></ul>
  </xsl:if>
</xsl:template>

<xsl:template match="item">
  <li>
  <xsl:if test="name">
    <b><xsl:value-of select="name"/></b>
  </xsl:if>
  <xsl:if test="name and desc">
    —
  </xsl:if>
  <xsl:if test="desc">
    <xsl:apply-templates select="desc"/>
  </xsl:if>
  <xsl:apply-templates select="olist|ulist|note"/>
  </li>
</xsl:template>

<xsl:template match="note">
  <div class="note">
    <div class="notelabel"><xsl:value-of select="label" /></div>
    <div class="notetext"><xsl:apply-templates select="desc"/></div>
  </div>
  <div class="notebuffer"></div>
</xsl:template>

<xsl:template match="feature_group/name">
  <xsl:apply-templates select="text()|app_name"/>
</xsl:template>

<xsl:template match="item/desc">
  <xsl:apply-templates select="text()|b|i|url|app_name"/>
</xsl:template>

<xsl:template match="desc">
  <p>
  <xsl:apply-templates select="text()|b|i|url|app_name"/>
  </p>
</xsl:template>

<xsl:template match="sep">
  <hr></hr>
</xsl:template>

<xsl:template match="footer">
  <p class="copyright_p"><xsl:copy-of select="." /></p>
</xsl:template>

<xsl:template match="b">
  <b>
  <xsl:apply-templates select="text()|app_name"/>
  </b>
</xsl:template>

<xsl:template match="i">
  <i>
  <xsl:apply-templates select="text()|app_name"/>
  </i>
</xsl:template>

<xsl:template match="url">
  <xsl:copy-of select="$url_factory/url[@id=current()/@id]" />
</xsl:template>

<xsl:template match="app_name">
  <xsl:value-of select="$app_name"/>
</xsl:template>

<xsl:template match="text()">
  <xsl:value-of select="."/>
</xsl:template>

</xsl:stylesheet>