<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:output method="html" version="4.0" encoding="UTF-8" indent="yes"/>

<xsl:variable name="url_factory" select="document(/contextual-help/url-path)/factory"/>
<xsl:variable name="feature_id" select="/contextual-help/feature-id"/>

<xsl:variable name="app_name" select="document('help_legal.xml')/legal/title"/>

<xsl:template match="contextual-help">
  <html>
    <xsl:attribute name="dir">
      <xsl:value-of select="document('dir.xml')/dir"/>
    </xsl:attribute>
  <body>
  <style type="text/css"><xsl:value-of select="css"/></style>
  <xsl:apply-templates select="document(module-path)/feature-group"/>
  </body>
  </html>
</xsl:template>

<xsl:template match="feature-group">
  <div id="{@id}" class="{@id}">
    <h2><a name="{@id}"><xsl:value-of select="name"/></a></h2>
    <xsl:apply-templates select="desc|ulist|olist|note"/>
    <xsl:apply-templates select="feature"/>
  </div>
</xsl:template>

<xsl:template match="feature">
  <div id="{@id}" class="{@id}">
    <h3><a name="{@id}"><xsl:value-of select="name"/></a></h3>
    <xsl:apply-templates select="desc|olist|ulist|note|sep"/>
  </div>
</xsl:template>

<xsl:template match="olist">
  <xsl:if test="name">
    <p><b><xsl:value-of select="name"/></b></p>
  </xsl:if>
  <xsl:if test="item">
    <ol><xsl:apply-templates select="item"/></ol>
  </xsl:if>
</xsl:template>

<xsl:template match="ulist">
  <xsl:if test="name">
    <p><b><xsl:value-of select="name"/></b></p>
  </xsl:if>
  <xsl:if test="item">
    <ul><xsl:apply-templates select="item"/></ul>
  </xsl:if>
</xsl:template>

<xsl:template match="item">
  <li>
  <p>
  <xsl:if test="name">
    <b><xsl:value-of select="name"/></b>
  </xsl:if>
  <xsl:if test="name and desc">
    —
  </xsl:if>
  <xsl:if test="desc">
    <xsl:apply-templates select="desc"/>
  </xsl:if>
  </p>
  <xsl:apply-templates select="olist|ulist"/>
  </li>
</xsl:template>

<xsl:template match="item/desc">
  <xsl:apply-templates select="text()|b|i|url|app_name"/>
</xsl:template>

<xsl:template match="desc">
  <p>
  <xsl:apply-templates select="text()|b|i|url|app_name"/>
  </p>
</xsl:template>

<xsl:template match="sep">
  <hr></hr>
</xsl:template>

<xsl:template match="b">
  <b>
  <xsl:apply-templates select="text()|app_name"/>
  </b>
</xsl:template>

<xsl:template match="i">
  <i>
  <xsl:apply-templates select="text()|app_name"/>
  </i>
</xsl:template>

<xsl:template match="url">
  <xsl:copy-of select="$url_factory/url[@id=current()/@id]" />
</xsl:template>

<xsl:template match="app_name">
  <xsl:value-of select="$app_name"/>
</xsl:template>

<xsl:template match="text()">
  <xsl:value-of select="."/>
</xsl:template>

</xsl:stylesheet>